<script setup lang="ts">
import { h, onMounted, ref, toRaw } from 'vue';

import { Page, type VbenFormProps } from '@vben/common-ui';

import { Space } from 'ant-design-vue';

import { useVbenVxeGrid, type VxeGridProps, vxeSortEvent } from '#/adapter/vxe-table';
import { maint } from '#/api/eims/report';

import { columns as dynamicColumns, querySchema } from './data';
// 数据是否初始化
const initFlag = ref(false);
const baseColumns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '设备名称',
    field: 'equName',
    width: 200,
    fixed: 'left'
  },
  {
    title: '资产编号',
    field: 'assetNo',
    width: 200,
    fixed: 'left'
  }
];
initColumns();

const formOptions: VbenFormProps = {
  commonConfig: {
    labelWidth: 80,
    componentProps: {
      allowClear: true
    }
  },
  schema: querySchema(),
  wrapperClass: 'grid-cols-1 md:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4',
  handleReset: async () => {
    // eslint-disable-next-line no-use-before-define
    const { formApi, reload } = tableApi;
    await formApi.resetForm();
    const formValues = formApi.form.values;
    formApi.setLatestSubmissionValues(formValues);
    await reload(formValues);
  }
};

const gridOptions: VxeGridProps = {
  checkboxConfig: {
    // 高亮
    highlight: true,
    // 翻页时保留选中状态
    reserve: true
    // 点击行选中
    // trigger: 'row'
  },
  border: true,
  size: 'mini',
  columns: dynamicColumns.value,
  height: 'auto',
  keepSource: true,
  pagerConfig: {
    // 默认条数
    pageSize: 20,
    // 分页可选条数
    pageSizes: [10, 20, 30, 50, 100, 200, 300, 500]
  },
  proxyConfig: {
    ajax: {
      query: async ({ page }, formValues = {}) => {
        // TODO 暂时解决动态修改表头后参数丢失问题
        // eslint-disable-next-line no-use-before-define
        const p = await tableApi.formApi.getValues();
        const params = toRaw(p);

        return await maint({
          pageNum: page.currentPage,
          pageSize: page.pageSize,
          ...params
        });
      }
    }
  },
  rowConfig: {
    isHover: true,
    keyField: 'maintReport'
  },
  sortConfig: {
    // 远程排序
    remote: true,
    // 支持多字段排序 默认关闭
    multiple: true
  },
  id: 'mainit-report-index'
};

const [BasicTable, tableApi] = useVbenVxeGrid({
  formOptions,
  gridOptions,
  gridEvents: {
    sortChange: (sortParams) => vxeSortEvent(tableApi, sortParams)
  }
});

onMounted(async () => {
  initListener();
  // await setupEquSelect();
});
const selYear = ref('');

function initListener() {
  tableApi.formApi.updateSchema([
    {
      component: 'DatePicker',
      componentProps: {
        onChange: (sYear: string) => {
          selYear.value = sYear;
        }
      },
      fieldName: 'selectYear'
    }
  ]);
}

function initColumns() {
  if (initFlag.value) {
    return false;
  }
  const dayNumbers = getMonthNumbers();
  const newColumns: VxeGridProps['columns'] = dayNumbers.map((month: number) => ({
    title: `${month}月`,
    field: `month_${month}`,
    align: 'center',
    slots: {
      default: ({ row }) => {
        const value = row[`month_${month}`];
        let className = '';

        switch (value) {
          case '保养中': {
            className = 'dot-blue';
            break;
          }
          case '已完成': {
            className = 'dot-green';
            break;
          }
          case '待保养': {
            className = 'dot-gray';
            break;
          }
          case '待验证': {
            className = 'dot-orange';
            break;
          }
          default: {
            return '-';
          }
        }

        return h('span', { class: className });
      }
    }
  }));
  dynamicColumns.value = [...(baseColumns || []), ...newColumns];
  initFlag.value = true;
}

function getMonthNumbers(): number[] {
  return Array.from({ length: 12 }, (_, i) => i + 1);
}
</script>

<template>
  <Page :auto-content-height="true">
    <div class="flex h-full gap-[8px]">
      <BasicTable class="flex-1 overflow-hidden" table-title="保养报表">
        <template #toolbar-tools>
          <Space>
            <span class="ml-4 mr-2">-</span>未生成计划 <span class="dot-gray ml-4"></span>待保养 <span class="dot-blue ml-4"></span>保养中 <span class="dot-orange ml-4"></span>待验证 <span class="dot-green ml-4"></span>已完成
          </Space>
        </template>
      </BasicTable>
    </div>
  </Page>
</template>
<style lang="less" scoped>
:deep(.dot-green) {
  display: inline-block;
  width: 10px;
  height: 10px;
  border-radius: 50%;
  background-color: #52c41a;
}

:deep(.dot-orange) {
  display: inline-block;
  width: 10px;
  height: 10px;
  border-radius: 50%;
  background-color: #faad14;
}

:deep(.dot-blue) {
  display: inline-block;
  width: 10px;
  height: 10px;
  border-radius: 50%;
  background-color: #2a5dd8;
}

:deep(.dot-purple) {
  display: inline-block;
  width: 10px;
  height: 10px;
  border-radius: 50%;
  background-color: #8a2ad8;
}
:deep(.dot-gray) {
  display: inline-block;
  width: 10px;
  height: 10px;
  border-radius: 50%;
  background-color: #d9d9d9;
}
</style>
